@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-static
 version: 1.5.0.3
-id: yesod-static-1.5.0.3-bad483d80e79ed7660a6a597a8fba4ed
-key: yesod_C29WbifCCpU5I6nEUHuIbj
+id: yesod-static-1.5.0.3-3ef7f4cc8703267a2b46f85407c212cd
+key: yesod_1bKzmQwf4gM4wmohFYo8Z3
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -23,40 +23,40 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-static-1.5.0.3
-hs-libraries: HSyesod-static-1.5.0.3-C29WbifCCpU5I6nEUHuIbj
+hs-libraries: HSyesod-static-1.5.0.3-1bKzmQwf4gM4wmohFYo8Z3
 depends:
     async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
-    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
+    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
-    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
+    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
+    conduit-extra-1.1.13.1-cf2e2742d7d01907ed25c65d155b9a5e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     cryptohash-0.11.9-1ce6a3e7b661f39b36d188b8c49a9b44
-    cryptohash-conduit-0.1.1-05dcab06357a80c7bc7ae6cbc9d0516f
-    css-text-0.1.2.1-5f08c8634ff151127fcfba990f98863f
-    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
+    cryptohash-conduit-0.1.1-47b3295c0113c272521557c8fe3e3989
+    css-text-0.1.2.1-fd7cfa8d457b06bb47b9d76e18d81e4c
+    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
-    file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
+    file-embed-0.0.10-c7da10dfba0f55c7c135317c0bfb8508
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
-    hjsmin-0.2.0.1-9b584074a533f56bfeee2bd0e05cbecb
-    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
-    mime-types-0.1.0.6-7d5f22022675c00ea07fd0f1df020c2e
+    hjsmin-0.2.0.1-e1b35dff57a1615feb3def2aad7209fb
+    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
+    mime-types-0.1.0.7-9c54fcb2a9f57168849ef5415f3582c2
     old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
-    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
+    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
-    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
-    wai-app-static-3.1.5-3b989702052826a001c0c96e312e032f
-    yesod-core-1.4.20.1-8dce2c1559c72b98aae15f98b85f32e0
+    wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
+    wai-app-static-3.1.5-4b08fd9013eda7d6300c1fd3284ff8ba
+    yesod-core-1.4.20.2-b3dddaeebe1e00a8ca9ebbc062ef002b
 haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
 haddock-html: /usr/share/doc/haskell-yesod-static/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
